﻿using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Threading.Tasks;

namespace MiddleWareTest
{
    /// <summary>
    /// 模拟权限验证中间件
    /// </summary>
    public class MyAuthMiddleware
    {
        private readonly RequestDelegate _next;
        private readonly ILogger _logger;

        public MyAuthMiddleware(RequestDelegate next, ILoggerFactory loggerFactory)
        {
            _next = next;
            _logger = loggerFactory.CreateLogger<MyAuthMiddleware>();

        }

        public async Task Invoke(HttpContext context)
        {
            if (context.Request.Path.HasValue)
            {
                if(context.Request.Path.Value == "/favicon.ico")
                {
                    return;
                }
                //这里模拟用户无权限访问
                if (context.Request.Path.Value == "/Forbidden")
                {
                    _logger.LogInformation("禁止访问");
                    context.Response.StatusCode = (int)HttpStatusCode.Forbidden;//可以直接返回状态码
                    //context.Response.Redirect("/403.html");//直接跳转到提示页
                    return;
                }
                //这里模拟用户请求报错
                else if (context.Request.Path.Value == "/InternalServerError")
                {
                    _logger.LogInformation("服务器错误");
                    context.Response.StatusCode = (int)HttpStatusCode.InternalServerError;//可以直接返回状态码
                    //context.Response.Redirect("/500.html");//直接跳转到提示页
                    return;
                }
                else
                {
                    _logger.LogInformation("权限正常");
                }
                //验证通过，走正常流程（不阻碍正常流程）
            }

            await _next.Invoke(context);
        }
    }

    public static class MyAuthExtensions
    {
        public static IApplicationBuilder UseMyAuth(this IApplicationBuilder app)
        {
            if (app == null)
            {
                throw new ArgumentNullException(nameof(app));
            }
            return app.UseMiddleware<MyAuthMiddleware>();
        }
    }
}
