﻿using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.Logging;
using Microsoft.Extensions.Options;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Threading.Tasks;

namespace MiddleWareTest
{
    /// <summary>
    /// 模拟记录请求者IP、请求Path中间件
    /// </summary>
    public class RequestIPMiddleware
    {
        private readonly RequestDelegate _next;
        private readonly ILogger _logger;
        private readonly RequestIPOptions _option;

        public RequestIPMiddleware(RequestDelegate next, ILoggerFactory loggerFactory, IOptions<RequestIPOptions> options)
        {
            _next = next;
            _logger = loggerFactory.CreateLogger<RequestIPMiddleware>();
            if (options != null)
            {
                _option = options.Value;
            }

        }

        public async Task Invoke(HttpContext context)
        {
            if (context.Request.Path.HasValue && context.Request.Path.Value != "/favicon.ico")
            {
                var ip = context.Connection.RemoteIpAddress.ToString();
                if (_option == null || _option.LogType == 0 || (ip != "127.0.0.1" && ip != "::1"))
                    _logger.LogInformation("User IP：{0},path：{1}", ip, context.Request.Path);
            }

            await _next.Invoke(context);
        }
    }
    public static class RequestIpExtensions
    {
        public static IApplicationBuilder UseRequestIP(this IApplicationBuilder app)
        {
            if (app == null)
            {
                throw new ArgumentNullException(nameof(app));
            }
            return app.UseMiddleware<RequestIPMiddleware>();
        }
        public static IApplicationBuilder UseRequestIP(this IApplicationBuilder app, RequestIPOptions options)
        {
            if (app == null)
            {
                throw new ArgumentNullException(nameof(app));
            }
            if (options == null)
            {
                throw new ArgumentNullException(nameof(options));
            }
            return app.UseMiddleware<RequestIPMiddleware>(Options.Create(options));
        }
    }
}
