﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Http;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.FileProviders;
using Microsoft.Extensions.Logging;

namespace MiddleWareTest
{
    public class Startup
    {
        // This method gets called by the runtime. Use this method to add services to the container.
        // For more information on how to configure your application, visit https://go.microsoft.com/fwlink/?LinkID=398940
        public void ConfigureServices(IServiceCollection services)
        {
        }

        // This method gets called by the runtime. Use this method to configure the HTTP request pipeline.
        public void Configure(IApplicationBuilder app, IHostingEnvironment env, ILoggerFactory loggerFactory)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }
            loggerFactory.AddConsole(minLevel: LogLevel.Information);//启用控制台输出log中间件
            app.UseRequestIP(new RequestIPOptions()
            {
                LogType = 0
            });//使用自已写的中间件

            app.UseMyAuth();

            app.UseStaticFiles();//静态文件，默认 wwwroot子目录
            //app.UseStaticFiles(new StaticFileOptions()
            //{
            //    FileProvider = new PhysicalFileProvider(Path.Combine(Directory.GetCurrentDirectory(), @"wwwroot")),
            //    RequestPath = new PathString("/")
            //});


            app.UseStaticFiles(new StaticFileOptions()
            {
                FileProvider = new PhysicalFileProvider(Path.Combine(Directory.GetCurrentDirectory(), @"content")),
                RequestPath = new PathString("/content")
            });//静态文件，content子目录

            //开启目录浏览
            app.UseDirectoryBrowser(new DirectoryBrowserOptions()
            {
                FileProvider = new PhysicalFileProvider(Path.Combine(Directory.GetCurrentDirectory(), @"content")),
                RequestPath = new PathString("/content")
            });
            app.Run(async (context) =>
            {
                if (context.Request.Path.HasValue && context.Request.Path.Value == "/")
                {
                    await context.Response.WriteAsync("Index Page! " + System.IO.Directory.GetCurrentDirectory());
                }
                else
                {
                    context.Response.StatusCode = 404;
                    await context.Response.WriteAsync("");
                }
            });

        }
    }
}
